#ifndef NT2_INCLUDE_FUNCTIONS_NEXTPOW2_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_NEXTPOW2_HPP_INCLUDED

#include <nt2/ieee/include/functions/nextpow2.hpp>

#endif
